Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config []Endpoint
Config represents a slice of many Endpoint structures, each representing a host and associated attack parameters.
type Endpoint ¶
type Endpoint struct {
URL string `yaml:"url"`
Database string `yaml:"database"`
Table string `yaml:"table"`
Column string `yaml:"column"`
Threads int `yaml:"threads"`
Retrieve `yaml:"retrieve"`
}
Endpoint is the principal struct in which we embed other structs for a given host's configuration
Click to show internal directories.
Click to hide internal directories.